# Airwaves Are Our Weapons
### An Introduction to Software Defined Radio for Anarchists, Insurgents, and Other Rebels


Traditionally, when we have discussed wireless communications, eavesdropping, and the building of communications networks it comes along with a sense of disempowerment. It is a discussion in which we often feel like passive observers, or those subject to the actions of others without recourse. It is a discussion that often plays out in the realm of courts and legislative activity, which, as anarchists, is not the sandbox that we usually play in. The terrain of engagement itself is owned by those that are allied with the state, and which provide it easy access to our private lives on request. We often view ourselves as operating on hostile lines, within hostile networks, whether that be a social media platform or something as basic as a phone call. The resulting discourse is one that often feels distant but impactful at the same time, impossible to touch even though its implications on our lives are significant. There is almost a spectrality to communications, but one that merely haunts us. This view is not incorrect; this is our reality...now. But, as we grow and come into increasing conflict with the state our capabilities need to change, and we need to become active protagonists in this story.

Unfortunately, in anarchist circles, the discourse around technology tends to be a bit reductionistic; either technology is an indicator of a structure of domestication that is killing us all, or it is the medium of our salvation. The reality is, though, that nothing is this simple, especially the technical. Technology is everything that us humans use to supplement our physical capabilities, everything, and as a result it is not something that can simply be avoided or destroyed, if that were even preferable. At the same time technology is also bound up with the entirety of the conditions of its creation and use, the appropriation of the capability for a purpose, in this case usually profit and repression. We can see glimpses of what a more complicated posture toward technology can look if we examine early hacker scenes. In the mid-1980s there was an online community referred to as WELL (Whole Earth ‘Lectronic Link), which was run by a group of old hippies that also ran the Whole Earth Catalog. The idea behind communities like WELL was to form spaces, outside of the control of the state or corporations, where autonomy could exist in the absence of being able to overthrow capitalism in reality. A utopianism grew, incorporating things like early virtual reality, in a narrative very similar to that of LSD in the late 1960s. It is this utopianism that forms the absurdities of current Silicon Valley politics, this idea that speech is something that happens in a bubble separate from the world, the idea that everyone should have access to every asset regardless of who they are and how they interact with others (even if they are using those assets to attack people), the idea that computers and the internet are always a better solution to a problem. It is a view that naively ignores the entirety of the space outside of it.  

At the same time there was a rising genre of cyberpunk literature that was starting to talk about the inverse, the ways that technology can function as a mechanism of control and the operation of political and economic power. These stories were filled with courageous underground hackers taking on the evil corporations that had bought and were destroying the world. In this narrative technology is a mechanism for standardization, the generation of automated worlds, the creation of worlds dominated by machines, in which the developers and owners of those machines become all-powerful. It is from here that a lot of the outlaw hacker mentality emerges from, and where much of the modern hacker subculture draws its roots from. The partisans of the hacker mentality eventually started breaking into systems at companies like TRW, and saw the sheer volume of data that was being kept about individual people. They invaded the WELL and started an open debate about computers and their political implications. The hackers who invaded the WELL were not arguing that technology was bad, or purely destructive, even; just that we cannot think of the technological as separate from the social, political, and economic context of its development, production, and use. This means, that for as much as it does make sense to be skeptical of the current uses of technology, the implements themselves can be turned to different uses, potentially even against the context of their production.

When discussions of technology occur in anarchist circles the tendency is to focus on implements that we are familiar with, phones, chat apps, email, and so on. On this level we are often interacting with things we consume; a cell phone, the internet, a computer, etc. This layer of interaction is one which is frequently determined, in large part, by things that we cannot, and do not, have very much control over. But, what is often missing from these discussions are the understandings and uses of lower level technologies, or technologies that exist on a level that we are able to exert control, in which there is less abstraction separating ourselves from the action we are taking. Let us take a simple example, the computer operating system. An operating system like Windows is a series of tools and layers of abstraction that allow us to operate a computer by clicking and typing things that we can read. Underlying this, though, there are numerous execution layers, from code abstractions, intermediary language environments, machine code, binary, and eventually electrons being run through magic rocks that we made think. Much of what hackers do that others think looks like magic is based on learning how to manipulate these other layers of the system, where there are less limitations, fewer abstraction layers, and a more direct relationship between the system and the user. When we get down to a lower level like this we are dealing with concepts of science and physics more than we are dealing with specific devices or machines, and those concepts can, and are, often used to manipulate systems in unintended ways. On this layer, if one can figure out how to execute the task they are trying to undertake, there are very few restrictions on what one is able to make the computer do, as long as it is logically consistent.

One of these lower layer technologies that we utilize all the time, almost constantly, that is often abstracted, but able to be directly controlled, is radio. When the term radio is used it is often to identify audio signals that travel over the air, and technically any radio signal could be heard as a sound wave, but this is a small spectrum of what radio is used for. In essence, radio waves are used everywhere, from our car dongles and garage door openers, all the way to satellite communications, the sending of data between space stations and Earth, radar, essentially anything wireless. Just for a second, stop and take a look around just the room you are in. Try to identify every wireless device you have in that space; think through what sort of data could be getting sent over the air, and what it would look like to interact with this data directly. It is sort of overwhelming, in most contexts, just how much radio functions in core elements of our lives, and this is just what we are immediately aware of. Radio is fundamentally different from many other technologies in one core way, it is almost entirely open to be used. The airwaves are artificially separated into bands by governments for the purpose of regulation. But, absent this artifice of legality, radio is able to be used by anyone to listen to or transmit anything that they are capable of figuring out how to receive or send out. It is more of a science, or a principle of physics, than a specific technology and, just as with low level computing, that gives us a lot of autonomy over how and why we use it.

With radio we can transmit data, voice, noise, random signals over hundreds of miles, using open airwaves, outside of networks controlled by our enemies. With radio we can eavesdrop on the state, and engage in signals intelligence as part of political actions. With radio we can develop our own communications protocols, devices to use those protocols, and ways to protect these signals from surveillance. In this guide we are going to discuss how to utilize radio, what equipment one would need for some simple operations, and some links out to more advanced materials for those that really want to continue to learn beyond the basics. Before getting into the practical skills involved in starting to engage with radio, let’s take a detour and talk a little bit about what radio is, and ways we can start to understand its importance.



## Background and Basics

The term radio is used in a colloquial sense to mean, often, the listening to frequencies of wavelengths in the audible spectrum; AM and FM radio, family band walkie talkies, etc. The concept of radio is much broader, however, as are the possibilities for its use (and misuse). Radio refers to the use of radio waves to send information wirelessly over some space. Radio waves, in turn, are electromagnetic waves of radiated energy traveling through the air. When we turn on the radio in a car (if anyone still uses analog radio in their car…) what is occurring is that the antenna on your car, which is just a metal pole with a wire running through it, is literally coming into physical contact with one of these waves. That wave is then sent as energy down the wire to the actual receiver, resulting in us hearing sound.

Just as a thought exercise, real quick, if we assume that radio signals, even for a single FM station, need to be present everywhere in order to be received, just start to think about how dense the airwaves are with signals. We have remote controls, car door lock systems, audible radio, radio frequencies used just to send things like satellite data, military communications, analog television, etc. The air around us is constantly saturated with these signals. Now, what is really amazing, and slightly dangerous, about radio is that any of these signals could be intercepted, made sense of (in the absence of encryption), or even broadcast. Just think of all of the possibilities!

The roots of radio and wireless transmission can be traced back to attempting to solve for the limitations of physical lines in the telegraph system, but the roots of the telegraph system trace back even further. The first high-speed long range communications systems were semaphore or optical telegraphs set up by Napoleonic armies to relay messages over long distances in short periods of time. The system consisted of these towers, spaced out 5-10 miles apart, which had flappable arms controlled from inside the tower. The pattern that the arms were in indicated a letter, and using this system messages could be sent over hundreds of miles in a couple of hours; a massive advantage in the military operations of the time.

![flappyarmtowers](flappyarmtowers.jpg)

Starting in the 1840s we started seeing the introduction of the electric telegraph. Using devices that you would need to crank to in order to generate power, it was possible to send messages over hundreds of miles almost instantly, by the comparative standards of the day. The early telegraph system was standardized in 1865 with the introduction of Morse Code. This system had two advantages over its optical precursors; it was not visible by the enemy, and messages could get sent more quickly.  This came at the cost, however, of the laying down of an entire infrastructural lattice to support this new wired system, which was expensive and prone to failure.

In the 1870’s James Clerk Maxwell developed the theory of electromagnetism, that it is possible for energy to travel over the air; prior to this all wavelengths were thought to be visible. The first radio waves were generated in a lab in 1886, quickly followed by Guglielmo Marconi building the first full radio system, which used a transmitter to send Morse Code to a receiver. By 1901 that signal was able to travel across the Atlantic Ocean, and by 1905 we started to see the rise of antenna technology, and the building of different types of antennas for different purposes. For the first couple of decades of modern radio all signals were intermittent, namely they sent pulses of electricity over the air, as we see with Morse Code messages. What most of us understand as radio today, the sending of audio in a constant stream, emerged during World War I with the advent of AM (amplitude modulation) radio, and the first commercial radio broadcast was sent out by Westinghouse on November 2, 1920.

With the advent of continuously broadcasting radio signals, communications changed forever, with messages being able to be sent in near real-time across large distances, reliably, and with full audio capabilities. A full discussion could now occur wirelessly, and one of the first places that change was felt was in the military. When militaries adopted radio technology it became possible to project force globally, keep vastly dispersed forces in communication, and organize logistics over thousands of miles. The use of radio created a problem however. Unlike telegraph lines, which would need to be manually tapped in order to intercept messages, radio signals could just be grabbed out of the air with the right equipment, giving birth to both modern communications security and the use of signals intelligence; giving birth to modern cryptography and ultimately the computer.

There is definitely a lot more history that we could review here. If you want to take a closer look into this history, see the resource guide at the end of this pamphlet.

On a technical level, radio broadcasts exist across a wide spectrum of signals referred to as the RF spectrum (the Radio Frequency Spectrum). These signals are measured in hertz, which measure the number of frequency cycles one could receive in one second. Often, when we come into contact with hertz, it is in the form of megahertz (MHz) or gigahertz (GHz). The radio spectrum is regulated, in the US, by the Federal Communications Commission, which regulates all communications infrastructure. The FCC has divided the radio spectrum up into different groupings of frequencies. For example Project 25 (P25) digital trunked radio systems (which we will get into more later) are used widely by police in the US, and those signals can be found between 136-174 MHz, 403-512 MHz, and 746-806 MHz. Every type of radio signal, from satellite communications all the way down to the Bluetooth headset connected to your phone is allocated some range within the overall radio frequency spectrum. A visual graph laying out all of the different bands and what they are allocated to can be found at https://www.ntia.doc.gov/files/ntia/publications/2003-allochrt.pdf. In other regions of the world these allocations will likely look similar, but may differ slightly.

Within the US the airwaves are considered public property, but are regulated, divided up, and sold by the FCC, functionally privatizing large amounts of the spectrum. There are some open bands, where it is legal to both transmit and receive, such as the Family Band that a lot of walkie talkies and baby monitors operate in, which is between 462 and 467 MHz. Most of the RF spectrum is able to be listened to without any sort of approval or licensing. Broadcasting, on the other hand,is heavily regulated, with various licensing exams provided by the FCC to obtain different levels of certification.  The reality is, though, that the FCC has incredibly limited enforcement capacity, often only taking less than 5 enforcement actions in a year, most of which are violations of rules by licensed broadcasters, and not about illegal broadcasting.

Though regulated and policed, the RF spectrum is relatively open to explore, and all sorts of information can be found this way. In this guide we are going to talk about getting set up, capturing basic signals, demodulating ADS-B signals (which identify the type, altitude, and speed of aircraft), and intercepting emergency radio in your local area. We have an entire world out there, full of information, (much of it is very useful for political resistance), and all we have to do is reach out and pluck it out of the air.


## Getting Started with Software Defined Radio

A lot of this all sounds very complicated, and most sources for information that one can find about traditional radio are obtuse and filled with craft language. Radio communities are largely made up of people that are highly technical, and who often have some electrical engineering knowledge. As a result they tend to be a bit closed, and often have informal gatekeeping structures in place, so information can be hard to find.  Personally, it took a few years of focused learning and messing with radio signals to feel like I had a grasp on this, and most of that was spent just trying to find the type of information presented here.

This exclusivity of radio communities is exacerbated by the fact that traditional hardware radio setups often involve massive antennas, thousands of dollars in obscure equipment, and an entire workbench to set up on.

![radiostation](radiostation.jpg)

Today, however, we are able to start learning about radio in a much simpler and cheaper way, through software defined radio. Software defined radio refers to the use of software configurations to modify what signals are received and transmitted by a piece of simple hardware, as opposed to intimidating looking hardware with a bunch of knobs. Software defined radio first emerged in the mid-1970s, in US military adjacent research programs. In this guide we are mostly going to be dealing with a subset of SDR, the RTL-SDR. The term RTL-SDR is a reference to the type of signals processing chip used on the board. Around a decade ago security researchers discovered that it was possible to access raw signal data on devices that were used to receive digital TV; the chip is called the RTL2832U.  Unlike traditional radio setups RTL-SDR setups usually consist of a laptop, open source tuning software, a USB dongle and a small antenna.  Using this equipment it is possible to receive signals, depending on the specific chip used, between 24 MHz and 1766 MHz, a relatively wide swath of the RF spectrum. 

The equipment is very cheap, often under $30, and it can be used with almost any computer. There is much more advanced and expensive hardware, with the ability to receive a larger amount of signals and often transmission capabilities. However, for what we are going to discuss in this guide, a simple RTL-SDR is sufficient.

## Setup

The purpose of learning to use software defined radio is so we can have direct control over what we are listening to, and what we do with those signals. That means that we are going to need to set up a listening post of our very own!

To set up a listening post you will need the following:

**Computer:**

SDR relies on a separate computer to process the data that is being received. The computer should preferably run Windows or Linux. Depending on what sort of interception you want to do, the computer could require up to 4 processor cores and 8 GB of RAM, with the preference being a system from the last 7-8 years. In projects we work on locally we usually are able to get by with a cheap used Thinkpad or an old gaming PC from a friend’s closet, as long as we are only using the system for radio.

![sdr](sdrsetup.jpg)

**RTL- SDR Dongle:**

There are a lot of variants of RTL-SDR dongles available, mostly online. These will range in quality from bootleg copies of working devices all the way up to dongles that can cost a couple hundred dollars. For our purposes all we need is a cheap RTL-SDR of good quality. We would suggest either getting the RTL-SDR Blog dongles (which is what we use) or something from NooElec, a company that makes consumer grade SDR hardware. Both are very capable devices for the price.

![dongle](dongle.jpg)

**USB Extension Cable:**

A computer motherboard throws off a lot of electromagnetic interference, and that can negatively impact the ability to receive signals clearly. A USB extension cable three feet in length or more will be sufficient to distance the receiver from the computer.

**Software:**

There is a lot of software out there, and we will be discussing some of these frameworks as we go. But, to just get started it is recommended that you download SDR#, if you are using Windows, or GQRX, if you are using Linux. Both frameworks are very capable, and can be used for a lot of different types of interception, but are also easy to use, free, and open source. Depending on the system you may need to install drivers as well. Follow instructions on https://www.rtl-sdr.com/rtl-sdr-quick-start-guide/ for more information and troubleshooting.

**A Good Listening Position:**

This is sometimes the hardest part of setting a system like this up. The ambient environment is full of other signals, electromagnetic waves, power lines, brick walls, and any number of other sources of interference; this is especially true for those of us in cities. It is definitely possible to receive signals using a computer on the ground floor of a building, in the middle of a room, but are likely to get far better reception if listening from a location that has limited interference. In the past we have set up listening posts in more rural areas on the edge of the city, as well as positioned listening posts on the third or fourth floor of a building, above the power lines. Generally, due to local police repression, we tend to keep antennas indoors and not visible from the outside of the building, but if that is not a concern, setting up antennas on a roof is the best option.

**A Solid Group of People:**

Listening to radio for hours on end can get tedious. Most of the time you are just sweeping ranges that do not have much going on, or it is a firehose of information, like a police scanner. Either way, it is important to take breaks. This sort of activity does take some work to learn and get comfortable with, so finding a group of people that is trusted, and that is interested in radio, is crucial.

